@@ -25,6 +25,7 @@
 #include <DFloatingWidget>
 #include <DAnchors>
 #include <DFontSizeManager>
+#include <DHiDPIHelper>
 
 #define App (static_cast<QApplication*>(QCoreApplication::instance()))
 MainWidget::MainWidget(QWidget *parent) :
@@ -257,7 +258,7 @@ void MainWidget::setupConnect()
 
 void MainWidget::retranslateUi(QWidget *Widget)
 {
-    Widget->setWindowTitle(QApplication::translate("Widget", "Widget", nullptr));
+//    Widget->setWindowTitle("Widget");
     m_tiplabel->setText(QApplication::translate("Widget", "Tips: The clearer the image is, the more accurate the text is", nullptr));
 //    m_copyBtn->setText(QApplication::translate("Widget", "Copy", nullptr));
     //    m_exportBtn->setText(QApplication::translate("Widget", "Export", nullptr));
@@ -385,10 +386,10 @@ void MainWidget::openImage(const QImage &img, const QString &name)
     if (!m_loadImagethread) {
         m_loadImagethread = QThread::create([ = ]() {
             QMutexLocker locker(&m_mutex);
-            m_result = TessOcrUtils::instance()->getRecogitionResult(m_currentImg, ResultType::RESULT_STRING);
+            m_result = PaddleOCRApp::instance()->getRecogitionResult(*m_currentImg);
             //判断程序是否退出
             if (1 == m_isEndThread) {
-                emit sigResult(m_result.result);
+                emit sigResult(m_result);
             }
         });
     }
@@ -399,8 +400,10 @@ void MainWidget::openImage(const QImage &img, const QString &name)
 void MainWidget::loadHtml(const QString &html)
 {
     if (!html.isEmpty()) {
+        m_frameStackLayout->setContentsMargins(20, 0, 5, 0);
         m_resultWidget->setCurrentWidget(m_plainTextEdit);
         m_plainTextEdit->appendHtml(html);
+//        m_plainTextEdit->setHtml(html);
     } else {
         resultEmpty();
     }
@@ -409,8 +412,10 @@ void MainWidget::loadHtml(const QString &html)
 void MainWidget::loadString(const QString &string)
 {
     if (!string.isEmpty()) {
+        m_frameStackLayout->setContentsMargins(20, 0, 5, 0);
         m_resultWidget->setCurrentWidget(m_plainTextEdit);
         m_plainTextEdit->appendPlainText(string);
+//        m_plainTextEdit->setText(string);
         //读取完了显示在最上方
         m_plainTextEdit->moveCursor(QTextCursor::Start) ;
         m_plainTextEdit->ensureCursorVisible() ;
@@ -428,6 +433,8 @@ void MainWidget::loadString(const QString &string)
 
 void MainWidget::resultEmpty()
 {
+    //修复未识别到文字没有居中对齐的问题
+    m_frameStackLayout->setContentsMargins(20, 0, 20, 0);
     m_resultWidget->setCurrentWidget(m_noResult);
     //新增如果未识别到，按钮置灰
     if (m_copyBtn) {
@@ -493,7 +500,7 @@ void MainWidget::slotCopy()
         m_plainTextEdit->copy();
     } else {
         QTextDocument *document = m_plainTextEdit->document();
-        DPlainTextEdit *tempTextEdit = new DPlainTextEdit(this);
+        QPlainTextEdit *tempTextEdit = new QPlainTextEdit(this);
         tempTextEdit->setDocument(document);
         tempTextEdit->selectAll();
         tempTextEdit->copy();
@@ -528,7 +535,7 @@ void MainWidget::slotExport()
     if (!m_imgName.isEmpty()) {
         fileName = QFileInfo(m_imgName).completeBaseName();
     } else {
-        fileName = tr("Results");
+        fileName = "Results";
     }
 
     QString file_path = QFileDialog::getSaveFileName(this, "save as", download + "/" + fileName, "*.txt");
@@ -560,11 +567,13 @@ void MainWidget::setIcons(DGuiApplicationHelper::ColorType themeType)
             m_frameStack->setPalette(pal);
         }
         if (m_tipIconLabel) {
-            m_tipIconLabel->setPixmap(QPixmap(":/assets/tip_dark.svg"));
+            QPixmap m_tipImage = DHiDPIHelper::loadNxPixmap(":/assets/tip_dark.svg");
+            m_tipIconLabel->setPixmap(m_tipImage);
             m_tipIconLabel->setFixedSize(QSize(14, 14));
         }
 
         if (m_copyBtn) {
+            QPixmap m_shadowImg = DHiDPIHelper::loadNxPixmap(":/mpimage/light/shadow.svg");
             m_copyBtn->setIcon(QIcon(":/assets/copy_dark.svg"));
             m_copyBtn->setIconSize(QSize(36, 36));
         }
@@ -624,7 +633,9 @@ void MainWidget::setIcons(DGuiApplicationHelper::ColorType themeType)
             m_frameStack->setPalette(pal);
         }
         if (m_tipIconLabel) {
-            m_tipIconLabel->setPixmap(QPixmap(":/assets/tip_light.svg"));
+            QPixmap m_tipImage = DHiDPIHelper::loadNxPixmap(":/assets/tip_light.svg");
+            m_tipIconLabel->setPixmap(m_tipImage);
+//            m_tipIconLabel->setPixmap(QPixmap(":/assets/tip_light.svg"));
             m_tipIconLabel->setFixedSize(QSize(14, 14));
         }
 
